
From: Christoph Hellwig <hch@lst.de>

Currently xfs has a per-bdev (and XFS filesystem uses up to three underlying
block devices) object that Al complained about loudly that it should be gone.

But for that to happen without rewriting half of XFS (and changing layering
in a way that we don't really want) we need an additional fs-private variable
in struct block_device.


---

 25-akpm/include/linux/fs.h |    7 +++++++
 1 files changed, 7 insertions(+)

diff -puN include/linux/fs.h~blockdev-bd_private include/linux/fs.h
--- 25/include/linux/fs.h~blockdev-bd_private	Mon Jan 12 13:48:56 2004
+++ 25-akpm/include/linux/fs.h	Mon Jan 12 13:48:56 2004
@@ -354,6 +354,13 @@ struct block_device {
 	int			bd_invalidated;
 	struct gendisk *	bd_disk;
 	struct list_head	bd_list;
+	/*
+	 * Private data.  You must have bd_claim'ed the block_device
+	 * to use this.  NOTE:  bd_claim allows an owner to claim
+	 * the same device multiple times, the owner must take special
+	 * care to not mess up bd_private for that case.
+	 */
+	unsigned long		bd_private;
 };
 
 /*

_
